@@ -30,7 +30,7 @@ import (
 	"strings"
 
 	"github.com/blang/semver"
-	"github.com/shirou/gopsutil/host"
+	"github.com/shirou/gopsutil/v3/host"
 	"github.com/spf13/cobra"
 
 	"github.com/pulumi/pulumi/pkg/v3/backend"
@@ -146,7 +146,7 @@ func getSummaryAbout(transitiveDependencies bool) summaryAbout {
 			result.Runtime = &runtime
 		}
 		if deps, err := getProgramDependenciesAbout(proj, pwd, transitiveDependencies); err != nil {
-			addError(err, "Failed to get information about the Puluimi program's plugins")
+			addError(err, "Failed to get information about the Pulumi program's plugins")
 		} else {
 			result.Dependencies = deps
 		}
