@@ -29,6 +29,8 @@ func assertConvertibleFrom(t *testing.T, to, from Type) {
 }
 
 func TestBindLiteral(t *testing.T) {
+	t.Parallel()
+
 	expr, diags := BindExpressionText("false", nil, hcl.Pos{})
 	assert.Len(t, diags, 0)
 	assertConvertibleFrom(t, BoolType, expr.Type())
@@ -95,6 +97,8 @@ type exprTestCase struct {
 }
 
 func TestBindBinaryOp(t *testing.T) {
+	t.Parallel()
+
 	env := environment(map[string]interface{}{
 		"a": NewOutputType(BoolType),
 		"b": NewPromiseType(BoolType),
@@ -132,7 +136,9 @@ func TestBindBinaryOp(t *testing.T) {
 		{x: "b && true", t: NewPromiseType(BoolType)},
 	}
 	for _, c := range cases {
+		c := c
 		t.Run(c.x, func(t *testing.T) {
+			t.Parallel()
 			expr, diags := BindExpressionText(c.x, scope, hcl.Pos{})
 			assert.Len(t, diags, 0)
 			assertConvertibleFrom(t, c.t, expr.Type())
@@ -144,6 +150,8 @@ func TestBindBinaryOp(t *testing.T) {
 }
 
 func TestBindConditional(t *testing.T) {
+	t.Parallel()
+
 	env := environment(map[string]interface{}{
 		"a": NewOutputType(BoolType),
 		"b": NewPromiseType(BoolType),
@@ -164,7 +172,9 @@ func TestBindConditional(t *testing.T) {
 		{x: "b ? b : b", t: NewPromiseType(BoolType)},
 	}
 	for _, c := range cases {
+		c := c
 		t.Run(c.x, func(t *testing.T) {
+			t.Parallel()
 			expr, diags := BindExpressionText(c.x, scope, hcl.Pos{})
 			assert.Len(t, diags, 0)
 			assertConvertibleFrom(t, c.t, expr.Type())
@@ -176,6 +186,8 @@ func TestBindConditional(t *testing.T) {
 }
 
 func TestBindFor(t *testing.T) {
+	t.Parallel()
+
 	// TODO: union collection types
 
 	env := environment(map[string]interface{}{
@@ -225,7 +237,9 @@ func TestBindFor(t *testing.T) {
 		{x: `[for v in []: v if i]`, t: NewPromiseType(NewListType(NoneType))},
 	}
 	for _, c := range cases {
+		c := c
 		t.Run(c.x, func(t *testing.T) {
+			t.Parallel()
 			expr, diags := BindExpressionText(c.x, scope, hcl.Pos{})
 			assert.Len(t, diags, 0)
 			assertConvertibleFrom(t, c.t, expr.Type())
@@ -237,6 +251,8 @@ func TestBindFor(t *testing.T) {
 }
 
 func TestBindFunctionCall(t *testing.T) {
+	t.Parallel()
+
 	env := environment(map[string]interface{}{
 		"f0": NewFunction(StaticFunctionSignature{
 			Parameters: []Parameter{
@@ -281,7 +297,9 @@ func TestBindFunctionCall(t *testing.T) {
 		{x: `f1("foo", c, d)`, t: NewOutputType(BoolType)},
 	}
 	for _, c := range cases {
+		c := c
 		t.Run(c.x, func(t *testing.T) {
+			t.Parallel()
 			expr, diags := BindExpressionText(c.x, scope, hcl.Pos{})
 			assert.Len(t, diags, 0)
 			assertConvertibleFrom(t, c.t, expr.Type())
@@ -293,6 +311,8 @@ func TestBindFunctionCall(t *testing.T) {
 }
 
 func TestBindIndex(t *testing.T) {
+	t.Parallel()
+
 	env := environment(map[string]interface{}{
 		"a": StringType,
 		"b": IntType,
@@ -348,7 +368,10 @@ func TestBindIndex(t *testing.T) {
 		{x: "o[b]", t: NewPromiseType(BoolType)},
 	}
 	for _, c := range cases {
+		c := c
 		t.Run(c.x, func(t *testing.T) {
+			t.Parallel()
+
 			expr, diags := BindExpressionText(c.x, scope, hcl.Pos{})
 			assert.Len(t, diags, 0)
 			assertConvertibleFrom(t, c.t, expr.Type())
@@ -360,6 +383,8 @@ func TestBindIndex(t *testing.T) {
 }
 
 func TestBindObjectCons(t *testing.T) {
+	t.Parallel()
+
 	env := environment(map[string]interface{}{
 		"a": StringType,
 		"b": NumberType,
@@ -389,7 +414,10 @@ func TestBindObjectCons(t *testing.T) {
 		{x: `{(a): a, (b): b, (i): c}`, t: NewPromiseType(mt)},
 	}
 	for _, c := range cases {
+		c := c
 		t.Run(c.x, func(t *testing.T) {
+			t.Parallel()
+
 			expr, diags := BindExpressionText(c.x, scope, hcl.Pos{})
 			assert.Len(t, diags, 0)
 			assertConvertibleFrom(t, c.t, expr.Type())
@@ -401,6 +429,8 @@ func TestBindObjectCons(t *testing.T) {
 }
 
 func TestBindRelativeTraversal(t *testing.T) {
+	t.Parallel()
+
 	env := environment(map[string]interface{}{
 		"a":  NewMapType(StringType),
 		"aa": NewMapType(NewOutputType(StringType)),
@@ -442,7 +472,10 @@ func TestBindRelativeTraversal(t *testing.T) {
 		{x: `[for v in f: v].foo`, t: NewPromiseType(StringType)},
 	}
 	for _, c := range cases {
+		c := c
 		t.Run(c.x, func(t *testing.T) {
+			t.Parallel()
+
 			expr, diags := BindExpressionText(c.x, scope, hcl.Pos{})
 			assert.Len(t, diags, 0)
 			assertConvertibleFrom(t, c.t, expr.Type())
@@ -454,6 +487,8 @@ func TestBindRelativeTraversal(t *testing.T) {
 }
 
 func TestBindScopeTraversal(t *testing.T) {
+	t.Parallel()
+
 	ot := NewObjectType(map[string]Type{
 		"foo": NewListType(StringType),
 		"bar": NewObjectType(map[string]Type{
@@ -512,7 +547,10 @@ func TestBindScopeTraversal(t *testing.T) {
 		{x: `o.bar.baz`, t: NewPromiseType(StringType)},
 	}
 	for _, c := range cases {
+		c := c
 		t.Run(c.x, func(t *testing.T) {
+			t.Parallel()
+
 			expr, diags := BindExpressionText(c.x, scope, hcl.Pos{})
 			assert.Len(t, diags, 0)
 			assertConvertibleFrom(t, c.t, expr.Type())
@@ -524,6 +562,8 @@ func TestBindScopeTraversal(t *testing.T) {
 }
 
 func TestBindSplat(t *testing.T) {
+	t.Parallel()
+
 	ot := NewObjectType(map[string]Type{
 		"foo": NewListType(StringType),
 		"bar": NewObjectType(map[string]Type{
@@ -579,7 +619,10 @@ func TestBindSplat(t *testing.T) {
 		//		{x: `r[*].bar.baz`, t: NewPromiseType(NewTupleType(StringType))},
 	}
 	for _, c := range cases {
+		c := c
 		t.Run(c.x, func(t *testing.T) {
+			t.Parallel()
+
 			expr, diags := BindExpressionText(c.x, scope, hcl.Pos{})
 			assert.Len(t, diags, 0)
 			assertConvertibleFrom(t, c.t, expr.Type())
@@ -591,6 +634,8 @@ func TestBindSplat(t *testing.T) {
 }
 
 func TestBindTemplate(t *testing.T) {
+	t.Parallel()
+
 	env := environment(map[string]interface{}{
 		"a": StringType,
 		"b": NumberType,
@@ -640,7 +685,10 @@ func TestBindTemplate(t *testing.T) {
 		{x: `"%{for v in l} v: ${v} %{endfor}"`, t: NewPromiseType(StringType)},
 	}
 	for _, c := range cases {
+		c := c
 		t.Run(c.x, func(t *testing.T) {
+			t.Parallel()
+
 			expr, diags := BindExpressionText(c.x, scope, hcl.Pos{})
 			assert.Len(t, diags, 0)
 			assertConvertibleFrom(t, c.t, expr.Type())
@@ -661,6 +709,8 @@ func TestBindTemplate(t *testing.T) {
 }
 
 func TestBindTupleCons(t *testing.T) {
+	t.Parallel()
+
 	env := environment(map[string]interface{}{
 		"a": NewOutputType(StringType),
 		"b": NewPromiseType(StringType),
@@ -675,7 +725,10 @@ func TestBindTupleCons(t *testing.T) {
 		{x: `[{"foo": "bar"}]`, t: NewTupleType(NewObjectType(map[string]Type{"foo": StringType}))},
 	}
 	for _, c := range cases {
+		c := c
 		t.Run(c.x, func(t *testing.T) {
+			t.Parallel()
+
 			expr, diags := BindExpressionText(c.x, scope, hcl.Pos{})
 			assert.Len(t, diags, 0)
 			assertConvertibleFrom(t, c.t, expr.Type())
@@ -687,6 +740,8 @@ func TestBindTupleCons(t *testing.T) {
 }
 
 func TestBindUnaryOp(t *testing.T) {
+	t.Parallel()
+
 	env := environment(map[string]interface{}{
 		"a": NumberType,
 		"b": BoolType,
@@ -709,7 +764,10 @@ func TestBindUnaryOp(t *testing.T) {
 		{x: `!f`, t: NewPromiseType(BoolType)},
 	}
 	for _, c := range cases {
+		c := c
 		t.Run(c.x, func(t *testing.T) {
+			t.Parallel()
+
 			expr, diags := BindExpressionText(c.x, scope, hcl.Pos{})
 			assert.Len(t, diags, 0)
 			assertConvertibleFrom(t, c.t, expr.Type())
