@@ -40,15 +40,17 @@ const (
 // TODO[pulumi/pulumi#8647]
 func skipWindows(t *testing.T) {
 	if runtime.GOOS == "windows" {
-		t.Skip("Skipped on Windows: TODO handle Windows paths in test logic")
+		t.Skip("Skipped on Windows: TODO handle Windows local paths in URIs")
 	}
 }
 
 func TestAssetSerialize(t *testing.T) {
-	skipWindows(t)
+	t.Parallel()
 
 	// Ensure that asset and archive serialization round trips.
-	{
+	t.Run("text asset", func(t *testing.T) {
+		t.Parallel()
+
 		text := "a test asset"
 		asset, err := NewTextAsset(text)
 		assert.Nil(t, err)
@@ -114,9 +116,13 @@ func TestAssetSerialize(t *testing.T) {
 			// Go 1.10 introduced breaking changes to archive/zip and archive/tar headers
 			assert.Equal(t, "27ab4a14a617df10cff3e1cf4e30cf510302afe56bf4cc91f84041c9f7b62fd8", archDes.Hash)
 		}
-	}
-	{
-		file := "/dev/null"
+	})
+	t.Run("path asset", func(t *testing.T) {
+		t.Parallel()
+
+		f, err := ioutil.TempFile("", "")
+		assert.Nil(t, err)
+		file := f.Name()
 		asset, err := NewPathAsset(file)
 		assert.Nil(t, err)
 		assert.Equal(t, "e3b0c44298fc1c149afbf4c8996fb92427ae41e4649b934ca495991b7852b855", asset.Hash)
@@ -152,8 +158,11 @@ func TestAssetSerialize(t *testing.T) {
 			// Go 1.10 introduced breaking changes to archive/zip and archive/tar headers
 			assert.Equal(t, "d2587a875f82cdf3d3e6cfe9f8c6e6032be5dde8c344466e664e628da15757b0", archDes.Hash)
 		}
-	}
-	{
+	})
+	t.Run("local uri asset", func(t *testing.T) {
+		t.Parallel()
+
+		skipWindows(t)
 		url := "file:///dev/null"
 		asset, err := NewURIAsset(url)
 		assert.Nil(t, err)
@@ -190,8 +199,10 @@ func TestAssetSerialize(t *testing.T) {
 			// Go 1.10 introduced breaking changes to archive/zip and archive/tar headers
 			assert.Equal(t, "d2587a875f82cdf3d3e6cfe9f8c6e6032be5dde8c344466e664e628da15757b0", archDes.Hash)
 		}
-	}
-	{
+	})
+	t.Run("path archive", func(t *testing.T) {
+		t.Parallel()
+
 		file, err := tempArchive("test", false)
 		assert.Nil(t, err)
 		defer func() { contract.IgnoreError(os.Remove(file)) }()
@@ -205,8 +216,11 @@ func TestAssetSerialize(t *testing.T) {
 		assert.True(t, archDes.IsPath())
 		assert.Equal(t, file, archDes.Path)
 		assert.Equal(t, "e3b0c44298fc1c149afbf4c8996fb92427ae41e4649b934ca495991b7852b855", archDes.Hash)
-	}
-	{
+	})
+	t.Run("uri archive", func(t *testing.T) {
+		t.Parallel()
+
+		skipWindows(t)
 		file, err := tempArchive("test", false)
 		assert.Nil(t, err)
 		defer func() { contract.IgnoreError(os.Remove(file)) }()
@@ -221,8 +235,11 @@ func TestAssetSerialize(t *testing.T) {
 		assert.True(t, archDes.IsURI())
 		assert.Equal(t, url, archDes.URI)
 		assert.Equal(t, "e3b0c44298fc1c149afbf4c8996fb92427ae41e4649b934ca495991b7852b855", archDes.Hash)
-	}
-	{
+	})
+	t.Run("local uri archive", func(t *testing.T) {
+		t.Parallel()
+
+		skipWindows(t)
 		file1, err := tempArchive("test", false)
 		assert.Nil(t, err)
 		defer func() { contract.IgnoreError(os.Remove(file1)) }()
@@ -238,8 +255,11 @@ func TestAssetSerialize(t *testing.T) {
 		arch3, err := NewURIArchive(url)
 		assert.Nil(t, err)
 		assert.True(t, arch1.Equals(arch3))
-	}
-	{
+	})
+	t.Run("nested archives", func(t *testing.T) {
+		t.Parallel()
+
+		skipWindows(t)
 		file, err := tempArchive("test", true)
 		assert.Nil(t, err)
 		defer func() { contract.IgnoreError(os.Remove(file)) }()
@@ -260,7 +280,7 @@ func TestAssetSerialize(t *testing.T) {
 		assert.Nil(t, err)
 		assert.Nil(t, arch4.EnsureHash())
 		assert.False(t, arch2.Equals(arch4))
-	}
+	})
 }
 
 func tempArchive(prefix string, fill bool) (string, error) {
@@ -292,6 +312,8 @@ func tempArchive(prefix string, fill bool) (string, error) {
 }
 
 func TestDeserializeMissingHash(t *testing.T) {
+	t.Parallel()
+
 	assetSer := (&Asset{Text: "asset"}).Serialize()
 	assetDes, isasset, err := DeserializeAsset(assetSer)
 	assert.Nil(t, err)
@@ -300,7 +322,7 @@ func TestDeserializeMissingHash(t *testing.T) {
 }
 
 func TestAssetFile(t *testing.T) {
-	skipWindows(t)
+	t.Parallel()
 
 	asset, err := NewPathAsset("../../../../pkg/resource/testdata/Fox.txt")
 	assert.Nil(t, err)
@@ -314,7 +336,7 @@ asset jumps over the archive.
 }
 
 func TestArchiveDir(t *testing.T) {
-	skipWindows(t)
+	t.Parallel()
 
 	arch, err := NewPathArchive("../../../../pkg/resource/testdata/test_dir")
 	assert.Nil(t, err)
@@ -329,7 +351,7 @@ func TestArchiveDir(t *testing.T) {
 }
 
 func TestArchiveTar(t *testing.T) {
-	skipWindows(t)
+	t.Parallel()
 
 	// Note that test data was generated using the Go 1.9 headers
 	arch, err := NewPathArchive("../../../../pkg/resource/testdata/test_dir.tar")
@@ -339,7 +361,7 @@ func TestArchiveTar(t *testing.T) {
 }
 
 func TestArchiveTgz(t *testing.T) {
-	skipWindows(t)
+	t.Parallel()
 
 	// Note that test data was generated using the Go 1.9 headers
 	arch, err := NewPathArchive("../../../../pkg/resource/testdata/test_dir.tgz")
@@ -349,7 +371,7 @@ func TestArchiveTgz(t *testing.T) {
 }
 
 func TestArchiveZip(t *testing.T) {
-	skipWindows(t)
+	t.Parallel()
 
 	// Note that test data was generated using the Go 1.9 headers
 	arch, err := NewPathArchive("../../../../pkg/resource/testdata/test_dir.zip")
@@ -359,7 +381,7 @@ func TestArchiveZip(t *testing.T) {
 }
 
 func TestArchiveJar(t *testing.T) {
-	skipWindows(t)
+	t.Parallel()
 
 	arch, err := NewPathArchive("../../../../pkg/resource/testdata/test_dir.jar")
 	assert.Nil(t, err)
@@ -389,6 +411,8 @@ func findRepositoryRoot() (string, error) {
 }
 
 func TestArchiveTarFiles(t *testing.T) {
+	t.Parallel()
+
 	// TODO[pulumi/pulumi#7976] flaky
 	t.Skip("Disabled due to flakiness. See #7976.")
 
@@ -403,6 +427,8 @@ func TestArchiveTarFiles(t *testing.T) {
 }
 
 func TestArchiveZipFiles(t *testing.T) {
+	t.Parallel()
+
 	t.Skip() // TODO[pulumi/pulumi#7147]
 	repoRoot, err := findRepositoryRoot()
 	assert.Nil(t, err)
@@ -416,7 +442,7 @@ func TestArchiveZipFiles(t *testing.T) {
 
 //nolint: gosec
 func TestNestedArchive(t *testing.T) {
-	skipWindows(t)
+	t.Parallel()
 
 	// Create temp dir and place some files.
 	dirName, err := ioutil.TempDir("", "")
@@ -451,14 +477,15 @@ func TestNestedArchive(t *testing.T) {
 	assert.Nil(t, err)
 	files := zipReader.File
 	assert.Len(t, files, 3)
-	assert.Equal(t, "foo/a.txt", files[0].Name)
-	assert.Equal(t, "foo/bar/b.txt", files[1].Name)
-	assert.Equal(t, "fake.txt", files[2].Name)
+
+	assert.Equal(t, "foo/a.txt", filepath.ToSlash(files[0].Name))
+	assert.Equal(t, "foo/bar/b.txt", filepath.ToSlash(files[1].Name))
+	assert.Equal(t, "fake.txt", filepath.ToSlash(files[2].Name))
 }
 
 //nolint: gosec
 func TestFileReferencedThroughMultiplePaths(t *testing.T) {
-	skipWindows(t)
+	t.Parallel()
 
 	// Create temp dir and place some files.
 	dirName, err := ioutil.TempDir("", "")
@@ -491,10 +518,12 @@ func TestFileReferencedThroughMultiplePaths(t *testing.T) {
 	assert.Nil(t, err)
 	files := zipReader.File
 	assert.Len(t, files, 1)
-	assert.Equal(t, "foo/bar/b.txt", files[0].Name)
+	assert.Equal(t, "foo/bar/b.txt", filepath.ToSlash(files[0].Name))
 }
 
 func TestFileExtentionSniffing(t *testing.T) {
+	t.Parallel()
+
 	assert.Equal(t, ArchiveFormat(ZIPArchive), detectArchiveFormat("./some/path/my.zip"))
 	assert.Equal(t, ArchiveFormat(TarArchive), detectArchiveFormat("./some/path/my.tar"))
 	assert.Equal(t, ArchiveFormat(TarGZIPArchive), detectArchiveFormat("./some/path/my.tar.gz"))
@@ -513,6 +542,8 @@ func TestFileExtentionSniffing(t *testing.T) {
 }
 
 func TestInvalidPathArchive(t *testing.T) {
+	t.Parallel()
+
 	// Create a temp file that is not an asset.
 	tmpFile, err := ioutil.TempFile("", "")
 	fileName := tmpFile.Name()
@@ -535,6 +566,7 @@ func validateTestDirArchive(t *testing.T, arch *Archive, expected int) {
 	subs := make(map[string]string)
 	for {
 		name, blob, err := r.Next()
+		name = filepath.ToSlash(name)
 		if err == io.EOF {
 			break
 		}
