@@ -25,3 +25,10 @@ import (
 func QnamePath(nm tokens.QName) string {
 	return strings.Replace(string(nm), tokens.QNameDelimiter, string(os.PathSeparator), -1)
 }
+
+// NamePath just cleans a name and makes sure it's appropriate to use as a path.
+func NamePath(nm tokens.Name) string {
+	// Currently this is a no-op because the set of chars allowed in a Name [A-Za-z0-9_.-] are also
+	// valid file names
+	return string(nm)
+}
