@@ -24,6 +24,7 @@ class OpType(str, Enum):
     """
     The granular CRUD operation performed on a particular resource during an update.
     """
+
     SAME = "same"
     CREATE = "create"
     UPDATE = "update"
@@ -53,11 +54,12 @@ class CancelEvent(BaseEvent):
     CancelEvent is emitted when the user initiates a cancellation of the update in progress, or
     the update successfully completes.
     """
+
     def __init__(self) -> None:
         pass
 
     @classmethod
-    def from_json(cls) -> 'CancelEvent':
+    def from_json(cls) -> "CancelEvent":
         return cls()
 
 
@@ -73,12 +75,13 @@ class StdoutEngineEvent(BaseEvent):
     color: str
         The color to render the message
     """
+
     def __init__(self, message: str, color: str) -> None:
         self.message = message
         self.color = color
 
     @classmethod
-    def from_json(cls, data: dict) -> 'StdoutEngineEvent':
+    def from_json(cls, data: dict) -> "StdoutEngineEvent":
         return cls(**data)
 
 
@@ -104,14 +107,17 @@ class DiagnosticEvent(BaseEvent):
     prefix: Optional[str]
         An optional prefix
     """
-    def __init__(self,
-                 message: str,
-                 color: str,
-                 severity: str,
-                 stream_id: Optional[int] = None,
-                 ephemeral: Optional[bool] = None,
-                 urn: Optional[str] = None,
-                 prefix: Optional[str] = None) -> None:
+
+    def __init__(
+        self,
+        message: str,
+        color: str,
+        severity: str,
+        stream_id: Optional[int] = None,
+        ephemeral: Optional[bool] = None,
+        urn: Optional[str] = None,
+        prefix: Optional[str] = None,
+    ) -> None:
         self.message = message
         self.color = color
         self.severity = severity
@@ -121,14 +127,16 @@ class DiagnosticEvent(BaseEvent):
         self.prefix = prefix
 
     @classmethod
-    def from_json(cls, data: dict) -> 'DiagnosticEvent':
-        return cls(message=data.get("message", ""),
-                   color=data.get("color", ""),
-                   severity=data.get("severity", ""),
-                   stream_id=data.get("streamId"),
-                   ephemeral=data.get("ephemeral"),
-                   urn=data.get("urn"),
-                   prefix=data.get("prefix"))
+    def from_json(cls, data: dict) -> "DiagnosticEvent":
+        return cls(
+            message=data.get("message", ""),
+            color=data.get("color", ""),
+            severity=data.get("severity", ""),
+            stream_id=data.get("streamId"),
+            ephemeral=data.get("ephemeral"),
+            urn=data.get("urn"),
+            prefix=data.get("prefix"),
+        )
 
 
 class PolicyEvent(BaseEvent):
@@ -154,15 +162,18 @@ class PolicyEvent(BaseEvent):
     resource_urn: Optional[str]
         The urn of the resource associated with this event
     """
-    def __init__(self,
-                 message: str,
-                 color: str,
-                 policy_name: str,
-                 policy_pack_name: str,
-                 policy_pack_version: str,
-                 policy_pack_version_tag: str,
-                 enforcement_level: str,
-                 resource_urn: Optional[str] = None) -> None:
+
+    def __init__(
+        self,
+        message: str,
+        color: str,
+        policy_name: str,
+        policy_pack_name: str,
+        policy_pack_version: str,
+        policy_pack_version_tag: str,
+        enforcement_level: str,
+        resource_urn: Optional[str] = None,
+    ) -> None:
         self.message = message
         self.color = color
         self.policy_name = policy_name
@@ -173,15 +184,17 @@ class PolicyEvent(BaseEvent):
         self.resource_urn = resource_urn
 
     @classmethod
-    def from_json(cls, data: dict) -> 'PolicyEvent':
-        return cls(message=data.get("message", ""),
-                   color=data.get("color", ""),
-                   policy_name=data.get("policyName", ""),
-                   policy_pack_name=data.get("policyPackName", ""),
-                   policy_pack_version=data.get("policyPackVersion", ""),
-                   policy_pack_version_tag=data.get("policyPackVersionTag", ""),
-                   enforcement_level=data.get("enforcementLevel", ""),
-                   resource_urn=data.get("resource_urn"))
+    def from_json(cls, data: dict) -> "PolicyEvent":
+        return cls(
+            message=data.get("message", ""),
+            color=data.get("color", ""),
+            policy_name=data.get("policyName", ""),
+            policy_pack_name=data.get("policyPackName", ""),
+            policy_pack_version=data.get("policyPackVersion", ""),
+            policy_pack_version_tag=data.get("policyPackVersionTag", ""),
+            enforcement_level=data.get("enforcementLevel", ""),
+            resource_urn=data.get("resource_urn"),
+        )
 
 
 class PreludeEvent(BaseEvent):
@@ -194,11 +207,12 @@ class PreludeEvent(BaseEvent):
         config contains the keys and values for the update.
         Encrypted configuration values may be blinded.
     """
+
     def __init__(self, config: Mapping[str, str]) -> None:
         self.config = config
 
     @classmethod
-    def from_json(cls, data: dict) -> 'PreludeEvent':
+    def from_json(cls, data: dict) -> "PreludeEvent":
         return cls(**data)
 
 
@@ -222,22 +236,27 @@ class SummaryEvent(BaseEvent):
         compatibility. For older clients this will map to the version, while for newer ones
         it will be the version tag prepended with "v".
     """
-    def __init__(self,
-                 maybe_corrupt: bool,
-                 duration_seconds: int,
-                 resource_changes: OpMap,
-                 policy_packs: Mapping[str, str]) -> None:
+
+    def __init__(
+        self,
+        maybe_corrupt: bool,
+        duration_seconds: int,
+        resource_changes: OpMap,
+        policy_packs: Mapping[str, str],
+    ) -> None:
         self.maybe_corrupt = maybe_corrupt
         self.duration_seconds = duration_seconds
         self.resource_changes = resource_changes
         self.policy_packs = policy_packs
 
     @classmethod
-    def from_json(cls, data: dict) -> 'SummaryEvent':
-        return cls(maybe_corrupt=data.get("maybeCorrupt", False),
-                   duration_seconds=data.get("durationSeconds", 0),
-                   resource_changes=data.get("resourceChanges", {}),
-                   policy_packs=data.get("PolicyPacks", {}))
+    def from_json(cls, data: dict) -> "SummaryEvent":
+        return cls(
+            maybe_corrupt=data.get("maybeCorrupt", False),
+            duration_seconds=data.get("durationSeconds", 0),
+            resource_changes=data.get("resourceChanges", {}),
+            policy_packs=data.get("PolicyPacks", {}),
+        )
 
 
 class DiffKind(str, Enum):
@@ -253,6 +272,7 @@ class DiffKind(str, Enum):
     * UPDATE: update indicates that the property was updated.
     * UPDATE_REPLACE: indicates that the property was updated and requires that the resource be replaced.
     """
+
     ADD = "add"
     ADD_REPLACE = "add-replace"
     DELETE = "delete"
@@ -272,14 +292,17 @@ class PropertyDiff(BaseEvent):
     input_diff: bool
         input_diff is true if this is a difference between old and new inputs rather than old state and new inputs.
     """
+
     def __init__(self, diff_kind: DiffKind, input_diff: bool) -> None:
         self.diff_kind = diff_kind
         self.input_diff = input_diff
 
     @classmethod
-    def from_json(cls, data: dict) -> 'PropertyDiff':
-        return cls(diff_kind=DiffKind(data.get("diffKind")),
-                   input_diff=data.get("inputDiff", False))
+    def from_json(cls, data: dict) -> "PropertyDiff":
+        return cls(
+            diff_kind=DiffKind(data.get("diffKind")),
+            input_diff=data.get("inputDiff", False),
+        )
 
 
 class StepEventStateMetadata(BaseEvent):
@@ -313,18 +336,21 @@ class StepEventStateMetadata(BaseEvent):
     init_errors: Optional[List[str]]
         init_errors is the set of errors encountered in the process of initializing resource.
     """
-    def __init__(self,
-                 type: str,  # pylint: disable=redefined-builtin
-                 urn: str,
-                 id: str,  # pylint: disable=redefined-builtin
-                 parent: str,
-                 provider: str,
-                 custom: Optional[bool] = None,
-                 delete: Optional[bool] = None,
-                 protect: Optional[bool] = None,
-                 inputs: Mapping[str, Any] = None,
-                 outputs: Mapping[str, Any] = None,
-                 init_errors: Optional[List[str]] = None):
+
+    def __init__(
+        self,
+        type: str,  # pylint: disable=redefined-builtin
+        urn: str,
+        id: str,  # pylint: disable=redefined-builtin
+        parent: str,
+        provider: str,
+        custom: Optional[bool] = None,
+        delete: Optional[bool] = None,
+        protect: Optional[bool] = None,
+        inputs: Mapping[str, Any] = None,
+        outputs: Mapping[str, Any] = None,
+        init_errors: Optional[List[str]] = None,
+    ):
         self.type = type
         self.urn = urn
         self.id = id
@@ -338,18 +364,20 @@ class StepEventStateMetadata(BaseEvent):
         self.init_errors = init_errors
 
     @classmethod
-    def from_json(cls, data: dict) -> 'StepEventStateMetadata':
-        return cls(type=data.get("type", ""),
-                   urn=data.get("urn", ""),
-                   id=data.get("id", ""),
-                   parent=data.get("parent", ""),
-                   provider=data.get("provider", ""),
-                   custom=data.get("custom"),
-                   delete=data.get("delete"),
-                   protect=data.get("protect"),
-                   inputs=data.get("inputs"),
-                   outputs=data.get("outputs"),
-                   init_errors=data.get("initErrors"))
+    def from_json(cls, data: dict) -> "StepEventStateMetadata":
+        return cls(
+            type=data.get("type", ""),
+            urn=data.get("urn", ""),
+            id=data.get("id", ""),
+            parent=data.get("parent", ""),
+            provider=data.get("provider", ""),
+            custom=data.get("custom"),
+            delete=data.get("delete"),
+            protect=data.get("protect"),
+            inputs=data.get("inputs"),
+            outputs=data.get("outputs"),
+            init_errors=data.get("initErrors"),
+        )
 
 
 class StepEventMetadata(BaseEvent):
@@ -380,17 +408,20 @@ class StepEventMetadata(BaseEvent):
     logical: Optional[bool]
         Logical is set if the step is a logical operation in the program.
     """
-    def __init__(self,
-                 op: OpType,
-                 urn: str,
-                 type: str,  # pylint: disable=redefined-builtin
-                 provider: str,
-                 old: Optional[StepEventStateMetadata] = None,
-                 new: Optional[StepEventStateMetadata] = None,
-                 keys: Optional[List[str]] = None,
-                 diffs: Optional[List[str]] = None,
-                 detailed_diff: Optional[Mapping[str, PropertyDiff]] = None,
-                 logical: Optional[bool] = None):
+
+    def __init__(
+        self,
+        op: OpType,
+        urn: str,
+        type: str,  # pylint: disable=redefined-builtin
+        provider: str,
+        old: Optional[StepEventStateMetadata] = None,
+        new: Optional[StepEventStateMetadata] = None,
+        keys: Optional[List[str]] = None,
+        diffs: Optional[List[str]] = None,
+        detailed_diff: Optional[Mapping[str, PropertyDiff]] = None,
+        logical: Optional[bool] = None,
+    ):
         self.op = op
         self.urn = urn
         self.type = type
@@ -403,54 +434,58 @@ class StepEventMetadata(BaseEvent):
         self.logical = logical
 
     @classmethod
-    def from_json(cls, data: dict) -> 'StepEventMetadata':
+    def from_json(cls, data: dict) -> "StepEventMetadata":
         old = data.get("old")
         new = data.get("new")
 
-        return cls(op=OpType(data.get("op", "")),
-                   urn=data.get("urn", ""),
-                   type=data.get("type", ""),
-                   provider=data.get("provider", ""),
-                   old=StepEventStateMetadata.from_json(old) if old else None,
-                   new=StepEventStateMetadata.from_json(new) if new else None,
-                   keys=data.get("keys"),
-                   diffs=data.get("diffs"),
-                   detailed_diff=data.get("detailed_diff"),
-                   logical=data.get("logical"))
+        return cls(
+            op=OpType(data.get("op", "")),
+            urn=data.get("urn", ""),
+            type=data.get("type", ""),
+            provider=data.get("provider", ""),
+            old=StepEventStateMetadata.from_json(old) if old else None,
+            new=StepEventStateMetadata.from_json(new) if new else None,
+            keys=data.get("keys"),
+            diffs=data.get("diffs"),
+            detailed_diff=data.get("detailed_diff"),
+            logical=data.get("logical"),
+        )
 
 
 class ResourcePreEvent(BaseEvent):
     """
     ResourcePreEvent is emitted before a resource is modified.
     """
-    def __init__(self,
-                 metadata: StepEventMetadata,
-                 planning: Optional[bool] = None):
+
+    def __init__(self, metadata: StepEventMetadata, planning: Optional[bool] = None):
         self.metadata = metadata
         self.planning = planning
 
     @classmethod
-    def from_json(cls, data: dict) -> 'ResourcePreEvent':
+    def from_json(cls, data: dict) -> "ResourcePreEvent":
         metadata: dict = data.get("metadata", {})
-        return cls(metadata=StepEventMetadata.from_json(metadata),
-                   planning=data.get("planning"))
+        return cls(
+            metadata=StepEventMetadata.from_json(metadata),
+            planning=data.get("planning"),
+        )
 
 
 class ResOutputsEvent(BaseEvent):
     """
     ResOutputsEvent is emitted when a resource is finished being provisioned.
     """
-    def __init__(self,
-                 metadata: StepEventMetadata,
-                 planning: Optional[bool] = None):
+
+    def __init__(self, metadata: StepEventMetadata, planning: Optional[bool] = None):
         self.metadata = metadata
         self.planning = planning
 
     @classmethod
-    def from_json(cls, data: dict) -> 'ResOutputsEvent':
+    def from_json(cls, data: dict) -> "ResOutputsEvent":
         metadata: dict = data.get("metadata", {})
-        return cls(metadata=StepEventMetadata.from_json(metadata),
-                   planning=data.get("planning"))
+        return cls(
+            metadata=StepEventMetadata.from_json(metadata),
+            planning=data.get("planning"),
+        )
 
 
 class ResOpFailedEvent(BaseEvent):
@@ -458,20 +493,20 @@ class ResOpFailedEvent(BaseEvent):
     ResOpFailedEvent is emitted when a resource operation fails. Typically a DiagnosticEvent is
     emitted before this event, indicating the root cause of the error.
     """
-    def __init__(self,
-                 metadata: StepEventMetadata,
-                 status: int,
-                 steps: int):
+
+    def __init__(self, metadata: StepEventMetadata, status: int, steps: int):
         self.metadata = metadata
         self.status = status
         self.steps = steps
 
     @classmethod
-    def from_json(cls, data: dict) -> 'ResOpFailedEvent':
+    def from_json(cls, data: dict) -> "ResOpFailedEvent":
         metadata: dict = data.get("metadata", {})
-        return cls(metadata=StepEventMetadata.from_json(metadata),
-                   status=data.get("status", 0),
-                   steps=data.get("steps", 0))
+        return cls(
+            metadata=StepEventMetadata.from_json(metadata),
+            status=data.get("status", 0),
+            steps=data.get("steps", 0),
+        )
 
 
 class EngineEvent(BaseEvent):
@@ -492,18 +527,21 @@ class EngineEvent(BaseEvent):
     timestamp: int
         Timestamp is a Unix timestamp (seconds) of when the event was emitted.
     """
-    def __init__(self,
-                 sequence: int,
-                 timestamp: int,
-                 cancel_event: Optional[CancelEvent] = None,
-                 stdout_event: Optional[StdoutEngineEvent] = None,
-                 diagnostic_event: Optional[DiagnosticEvent] = None,
-                 prelude_event: Optional[PreludeEvent] = None,
-                 summary_event: Optional[SummaryEvent] = None,
-                 resource_pre_event: Optional[ResourcePreEvent] = None,
-                 res_outputs_event: Optional[ResOutputsEvent] = None,
-                 res_op_failed_event: Optional[ResOpFailedEvent] = None,
-                 policy_event: Optional[PolicyEvent] = None):
+
+    def __init__(
+        self,
+        sequence: int,
+        timestamp: int,
+        cancel_event: Optional[CancelEvent] = None,
+        stdout_event: Optional[StdoutEngineEvent] = None,
+        diagnostic_event: Optional[DiagnosticEvent] = None,
+        prelude_event: Optional[PreludeEvent] = None,
+        summary_event: Optional[SummaryEvent] = None,
+        resource_pre_event: Optional[ResourcePreEvent] = None,
+        res_outputs_event: Optional[ResOutputsEvent] = None,
+        res_op_failed_event: Optional[ResOpFailedEvent] = None,
+        policy_event: Optional[PolicyEvent] = None,
+    ):
         self.sequence = sequence
         self.timestamp = timestamp
         self.cancel_event = cancel_event
@@ -517,7 +555,7 @@ class EngineEvent(BaseEvent):
         self.policy_event = policy_event
 
     @classmethod
-    def from_json(cls, data: dict) -> 'EngineEvent':
+    def from_json(cls, data: dict) -> "EngineEvent":
         stdout_event = data.get("stdoutEvent")
         diagnostic_event = data.get("diagnosticEvent")
         prelude_event = data.get("preludeEvent")
@@ -527,14 +565,30 @@ class EngineEvent(BaseEvent):
         res_op_failed_event = data.get("resOpFailedEvent")
         policy_event = data.get("policyEvent")
 
-        return cls(sequence=data.get("sequence", 0),
-                   timestamp=data.get("timestamp", 0),
-                   cancel_event=CancelEvent() if "cancelEvent" in data else None,
-                   stdout_event=StdoutEngineEvent.from_json(stdout_event) if stdout_event else None,
-                   diagnostic_event=DiagnosticEvent.from_json(diagnostic_event) if diagnostic_event else None,
-                   prelude_event=PreludeEvent.from_json(prelude_event) if prelude_event else None,
-                   summary_event=SummaryEvent.from_json(summary_event) if summary_event else None,
-                   resource_pre_event=ResourcePreEvent.from_json(resource_pre_event) if resource_pre_event else None,
-                   res_outputs_event=ResOutputsEvent.from_json(res_outputs_event) if res_outputs_event else None,
-                   res_op_failed_event=ResOpFailedEvent.from_json(res_op_failed_event) if res_op_failed_event else None,
-                   policy_event=PolicyEvent.from_json(policy_event) if policy_event else None)
+        return cls(
+            sequence=data.get("sequence", 0),
+            timestamp=data.get("timestamp", 0),
+            cancel_event=CancelEvent() if "cancelEvent" in data else None,
+            stdout_event=StdoutEngineEvent.from_json(stdout_event)
+            if stdout_event
+            else None,
+            diagnostic_event=DiagnosticEvent.from_json(diagnostic_event)
+            if diagnostic_event
+            else None,
+            prelude_event=PreludeEvent.from_json(prelude_event)
+            if prelude_event
+            else None,
+            summary_event=SummaryEvent.from_json(summary_event)
+            if summary_event
+            else None,
+            resource_pre_event=ResourcePreEvent.from_json(resource_pre_event)
+            if resource_pre_event
+            else None,
+            res_outputs_event=ResOutputsEvent.from_json(res_outputs_event)
+            if res_outputs_event
+            else None,
+            res_op_failed_event=ResOpFailedEvent.from_json(res_op_failed_event)
+            if res_op_failed_event
+            else None,
+            policy_event=PolicyEvent.from_json(policy_event) if policy_event else None,
+        )
