@@ -15,7 +15,22 @@ import asyncio
 import os
 import traceback
 
-from typing import Optional, Any, Callable, List, NamedTuple, Dict, Set, Tuple, Union, TYPE_CHECKING, cast, Mapping, Sequence, Iterable
+from typing import (
+    Optional,
+    Any,
+    Callable,
+    List,
+    NamedTuple,
+    Dict,
+    Set,
+    Tuple,
+    Union,
+    TYPE_CHECKING,
+    cast,
+    Mapping,
+    Sequence,
+    Iterable,
+)
 from google.protobuf import struct_pb2
 import grpc
 
@@ -78,22 +93,26 @@ class ResourceResolverOperations(NamedTuple):
 
 # Prepares for an RPC that will manufacture a resource, and hence deals with input and output properties.
 # pylint: disable=too-many-locals
-async def prepare_resource(res: 'Resource',
-                           ty: str,
-                           custom: bool,
-                           remote: bool,
-                           props: 'Inputs',
-                           opts: Optional['ResourceOptions'],
-                           typ: Optional[type] = None) -> ResourceResolverOperations:
+async def prepare_resource(
+    res: "Resource",
+    ty: str,
+    custom: bool,
+    remote: bool,
+    props: "Inputs",
+    opts: Optional["ResourceOptions"],
+    typ: Optional[type] = None,
+) -> ResourceResolverOperations:
 
     # Before we can proceed, all our dependencies must be finished.
     explicit_urn_dependencies: Set[str] = set()
     if opts is not None and opts.depends_on is not None:
-        explicit_urn_dependencies = await _resolve_depends_on_urns(opts, from_resource=res)
+        explicit_urn_dependencies = await _resolve_depends_on_urns(
+            opts, from_resource=res
+        )
 
     # Serialize out all our props to their final values.  In doing so, we'll also collect all
     # the Resources pointed to by any Dependency objects we encounter, adding them to 'implicit_dependencies'.
-    property_dependencies_resources: Dict[str, List['Resource']] = {}
+    property_dependencies_resources: Dict[str, List["Resource"]] = {}
 
     # If we have type information, we'll use it for translations rather than the resource's translate_input_property.
     translate: Optional[Callable[[str], str]] = res.translate_input_property
@@ -102,8 +121,13 @@ async def prepare_resource(res: 'Resource',
 
     # To initially scope the use of this new feature, we only keep output values when
     # remote is true (for multi-lang components).
-    serialized_props = await rpc.serialize_properties(props, property_dependencies_resources, translate, typ,
-        keep_output_values=remote)
+    serialized_props = await rpc.serialize_properties(
+        props,
+        property_dependencies_resources,
+        translate,
+        typ,
+        keep_output_values=remote,
+    )
 
     # Wait for our parent to resolve
     parent_urn: Optional[str] = ""
@@ -168,7 +192,9 @@ async def prepare_resource(res: 'Resource',
     )
 
 
-def resource_output(res: 'Resource') -> Tuple[Callable[[Any, bool, bool, Optional[Exception]], None], 'Output']:
+def resource_output(
+    res: "Resource",
+) -> Tuple[Callable[[Any, bool, bool, Optional[Exception]], None], "Output"]:
 
     value_future: asyncio.Future[Any] = asyncio.Future()
     known_future: asyncio.Future[bool] = asyncio.Future()
@@ -187,11 +213,9 @@ def resource_output(res: 'Resource') -> Tuple[Callable[[Any, bool, bool, Optiona
     return resolve, Output({res}, value_future, known_future, secret_future)
 
 
-def get_resource(res: 'Resource',
-                 props: 'Inputs',
-                 custom: bool,
-                 urn: str,
-                 typ: Optional[type] = None) -> None:
+def get_resource(
+    res: "Resource", props: "Inputs", custom: bool, urn: str, typ: Optional[type] = None
+) -> None:
     log.debug(f"getting resource: urn={urn}")
 
     # If we have type information, we'll use its and the resource's type/name metadata
@@ -219,7 +243,9 @@ def get_resource(res: 'Resource',
 
             monitor = settings.get_monitor()
             inputs = await rpc.serialize_properties({"urn": urn}, {})
-            req = provider_pb2.InvokeRequest(tok="pulumi:pulumi:getResource", args=inputs, provider="", version="")
+            req = provider_pb2.InvokeRequest(
+                tok="pulumi:pulumi:getResource", args=inputs, provider="", version=""
+            )
 
             def do_invoke():
                 try:
@@ -232,11 +258,14 @@ def get_resource(res: 'Resource',
 
             # If the invoke failed, raise an error.
             if resp.failures:
-                raise Exception(f"getResource failed: {resp.failures[0].reason} ({resp.failures[0].property})")
+                raise Exception(
+                    f"getResource failed: {resp.failures[0].reason} ({resp.failures[0].property})"
+                )
 
         except Exception as exn:
             log.debug(
-                f"exception when preparing or executing rpc: {traceback.format_exc()}")
+                f"exception when preparing or executing rpc: {traceback.format_exc()}"
+            )
             rpc.resolve_outputs_due_to_exception(resolvers, exn)
             resolve_urn(None, True, False, exn)
             if resolve_id is not None:
@@ -244,7 +273,7 @@ def get_resource(res: 'Resource',
             raise
 
         # Otherwise, grab the URN, ID, and output properties and resolve all of them.
-        resp = getattr(resp, 'return')
+        resp = getattr(resp, "return")
 
         log.debug(f"getResource completed successfully: ty={ty}, urn={resp['urn']}")
         resolve_urn(resp["urn"], True, False, None)
@@ -255,63 +284,81 @@ def get_resource(res: 'Resource',
             is_known = bool(resp["id"])
             resolve_id(resp["id"], is_known, False, None)
 
-        rpc.resolve_outputs(res, resolver.serialized_props, resp["state"], {}, resolvers, transform_using_type_metadata)
+        rpc.resolve_outputs(
+            res,
+            resolver.serialized_props,
+            resp["state"],
+            {},
+            resolvers,
+            transform_using_type_metadata,
+        )
 
     asyncio.ensure_future(RPC_MANAGER.do_rpc("get resource", do_get)())
 
 
-def _translate_ignore_changes(res: 'Resource',
-                              typ: Optional[type],
-                              ignore_changes: Optional[List[str]]) -> Optional[List[str]]:
+def _translate_ignore_changes(
+    res: "Resource", typ: Optional[type], ignore_changes: Optional[List[str]]
+) -> Optional[List[str]]:
     if ignore_changes is not None:
         if typ is not None:
             # If `typ` is specified, use its type/name metadata for translation.
             input_names = _types.input_type_py_to_pulumi_names(typ)
-            ignore_changes = list(map(lambda k: input_names.get(k) or k, ignore_changes))
+            ignore_changes = list(
+                map(lambda k: input_names.get(k) or k, ignore_changes)
+            )
         elif res.translate_input_property is not None:
             ignore_changes = list(map(res.translate_input_property, ignore_changes))
     return ignore_changes
 
 
-def _translate_additional_secret_outputs(res: 'Resource',
-                                         typ: Optional[type],
-                                         additional_secret_outputs: Optional[List[str]]) -> Optional[List[str]]:
+def _translate_additional_secret_outputs(
+    res: "Resource", typ: Optional[type], additional_secret_outputs: Optional[List[str]]
+) -> Optional[List[str]]:
     if additional_secret_outputs is not None:
         if typ is not None:
             # If a `typ` is specified, we've opt-ed in to doing translations using type/name metadata rather
             # than using the resource's tranlate_input_property. Use the resource's metadata to translate.
             output_names = _types.resource_py_to_pulumi_names(type(res))
-            additional_secret_outputs = list(map(lambda k: output_names.get(k) or k, additional_secret_outputs))
+            additional_secret_outputs = list(
+                map(lambda k: output_names.get(k) or k, additional_secret_outputs)
+            )
         elif res.translate_input_property is not None:
             # Note that while `additional_secret_outputs` lists property names that are outputs, we
             # call `translate_input_property` because it is the method that converts from the
             # language projection name to the provider name, which is what we want.
-            additional_secret_outputs = list(map(res.translate_input_property, additional_secret_outputs))
+            additional_secret_outputs = list(
+                map(res.translate_input_property, additional_secret_outputs)
+            )
     return additional_secret_outputs
 
 
-def _translate_replace_on_changes(res: 'Resource',
-                                  typ: Optional[type],
-                                  replace_on_changes: Optional[List[str]]) -> Optional[List[str]]:
+def _translate_replace_on_changes(
+    res: "Resource", typ: Optional[type], replace_on_changes: Optional[List[str]]
+) -> Optional[List[str]]:
     if replace_on_changes is not None:
         if typ is not None:
             # If `typ` is specified, use its type/name metadata for translation.
             input_names = _types.input_type_py_to_pulumi_names(typ)
-            replace_on_changes = list(map(lambda k: input_names.get(k) or k, replace_on_changes))
+            replace_on_changes = list(
+                map(lambda k: input_names.get(k) or k, replace_on_changes)
+            )
         elif res.translate_input_property is not None:
-            replace_on_changes = list(map(res.translate_input_property, replace_on_changes))
+            replace_on_changes = list(
+                map(res.translate_input_property, replace_on_changes)
+            )
     return replace_on_changes
 
 
-def read_resource(res: 'CustomResource',
-                  ty: str,
-                  name: str,
-                  props: 'Inputs',
-                  opts: 'ResourceOptions',
-                  typ: Optional[type] = None) -> None:
+def read_resource(
+    res: "CustomResource",
+    ty: str,
+    name: str,
+    props: "Inputs",
+    opts: "ResourceOptions",
+    typ: Optional[type] = None,
+) -> None:
     if opts.id is None:
-        raise Exception(
-            "Cannot read resource whose options are lacking an ID value")
+        raise Exception("Cannot read resource whose options are lacking an ID value")
 
     log.debug(f"reading resource: ty={ty}, name={name}, id={opts.id}")
     monitor = settings.get_monitor()
@@ -352,9 +399,14 @@ def read_resource(res: 'CustomResource',
 
             # These inputs will end up in the snapshot, so if there are any additional secret
             # outputs, record them here.
-            additional_secret_outputs = _translate_additional_secret_outputs(res, typ, opts.additional_secret_outputs)
+            additional_secret_outputs = _translate_additional_secret_outputs(
+                res, typ, opts.additional_secret_outputs
+            )
 
-            accept_resources = not (os.getenv("PULUMI_DISABLE_RESOURCE_REFERENCES", "").upper() in {"TRUE", "1"})
+            accept_resources = not (
+                os.getenv("PULUMI_DISABLE_RESOURCE_REFERENCES", "").upper()
+                in {"TRUE", "1"}
+            )
             req = resource_pb2.ReadResourceRequest(
                 type=ty,
                 name=name,
@@ -371,12 +423,15 @@ def read_resource(res: 'CustomResource',
             )
 
             from ..resource import create_urn  # pylint: disable=import-outside-toplevel
+
             mock_urn = await create_urn(name, ty, resolver.parent_urn).future()
 
             def do_rpc_call():
                 if monitor is None:
                     # If no monitor is available, we'll need to fake up a response, for testing.
-                    return RegisterResponse(mock_urn, None, resolver.serialized_props, None)
+                    return RegisterResponse(
+                        mock_urn, None, resolver.serialized_props, None
+                    )
 
                 # If there is a monitor available, make the true RPC request to the engine.
                 try:
@@ -389,7 +444,8 @@ def read_resource(res: 'CustomResource',
 
         except Exception as exn:
             log.debug(
-                f"exception when preparing or executing rpc: {traceback.format_exc()}")
+                f"exception when preparing or executing rpc: {traceback.format_exc()}"
+            )
             rpc.resolve_outputs_due_to_exception(resolvers, exn)
             resolve_urn(None, True, False, exn)
             resolve_id(None, True, False, exn)
@@ -398,28 +454,38 @@ def read_resource(res: 'CustomResource',
         log.debug(f"resource read successful: ty={ty}, urn={resp.urn}")
         resolve_urn(resp.urn, True, False, None)
         resolve_id(resolved_id, True, False, None)  # Read IDs are always known.
-        rpc.resolve_outputs(res, resolver.serialized_props, resp.properties, {}, resolvers,
-                            transform_using_type_metadata)
+        rpc.resolve_outputs(
+            res,
+            resolver.serialized_props,
+            resp.properties,
+            {},
+            resolvers,
+            transform_using_type_metadata,
+        )
 
     asyncio.ensure_future(RPC_MANAGER.do_rpc("read resource", do_read)())
 
 
-def register_resource(res: 'Resource',
-                      ty: str,
-                      name: str,
-                      custom: bool,
-                      remote: bool,
-                      new_dependency: Callable[[str], 'Resource'],
-                      props: 'Inputs',
-                      opts: Optional['ResourceOptions'],
-                      typ: Optional[type] = None) -> None:
+def register_resource(
+    res: "Resource",
+    ty: str,
+    name: str,
+    custom: bool,
+    remote: bool,
+    new_dependency: Callable[[str], "Resource"],
+    props: "Inputs",
+    opts: Optional["ResourceOptions"],
+    typ: Optional[type] = None,
+) -> None:
     """
     Registers a new resource object with a given type t and name.  It returns the
     auto-generated URN and the ID that will resolve after the deployment has completed.  All
     properties will be initialized to property objects that the registration operation will resolve
     at the right time (or remain unresolved for deployments).
     """
-    log.debug(f"registering resource: ty={ty}, name={name}, custom={custom}, remote={remote}")
+    log.debug(
+        f"registering resource: ty={ty}, name={name}, custom={custom}, remote={remote}"
+    )
     monitor = settings.get_monitor()
 
     # If we have type information, we'll use its and the resource's type/name metadata
@@ -450,12 +516,17 @@ def register_resource(res: 'Resource',
 
             property_dependencies = {}
             for key, deps in resolver.property_dependencies.items():
-                property_dependencies[key] = resource_pb2.RegisterResourceRequest.PropertyDependencies(
-                    urns=deps)
+                property_dependencies[
+                    key
+                ] = resource_pb2.RegisterResourceRequest.PropertyDependencies(urns=deps)
 
             ignore_changes = _translate_ignore_changes(res, typ, opts.ignore_changes)
-            additional_secret_outputs = _translate_additional_secret_outputs(res, typ, opts.additional_secret_outputs)
-            replace_on_changes = _translate_replace_on_changes(res, typ, opts.replace_on_changes)
+            additional_secret_outputs = _translate_additional_secret_outputs(
+                res, typ, opts.additional_secret_outputs
+            )
+            replace_on_changes = _translate_replace_on_changes(
+                res, typ, opts.replace_on_changes
+            )
 
             # Translate the CustomTimeouts object.
             custom_timeouts = None
@@ -471,16 +542,22 @@ def register_resource(res: 'Resource',
                         custom_timeouts.delete = opts.custom_timeouts.delete
                 # Or, it could be a workaround passing in a dict.
                 elif isinstance(opts.custom_timeouts, dict):
-                    if 'create' in opts.custom_timeouts:
-                        custom_timeouts.create = opts.custom_timeouts['create']
-                    if 'update' in opts.custom_timeouts:
-                        custom_timeouts.update = opts.custom_timeouts['update']
-                    if 'delete' in opts.custom_timeouts:
-                        custom_timeouts.delete = opts.custom_timeouts['delete']
+                    if "create" in opts.custom_timeouts:
+                        custom_timeouts.create = opts.custom_timeouts["create"]
+                    if "update" in opts.custom_timeouts:
+                        custom_timeouts.update = opts.custom_timeouts["update"]
+                    if "delete" in opts.custom_timeouts:
+                        custom_timeouts.delete = opts.custom_timeouts["delete"]
                 else:
-                    raise Exception("Expected custom_timeouts to be a CustomTimeouts object")
+                    raise Exception(
+                        "Expected custom_timeouts to be a CustomTimeouts object"
+                    )
+
+            accept_resources = not (
+                os.getenv("PULUMI_DISABLE_RESOURCE_REFERENCES", "").upper()
+                in {"TRUE", "1"}
+            )
 
-            accept_resources = not (os.getenv("PULUMI_DISABLE_RESOURCE_REFERENCES", "").upper() in {"TRUE", "1"})
             req = resource_pb2.RegisterResourceRequest(
                 type=ty,
                 name=name,
@@ -506,15 +583,19 @@ def register_resource(res: 'Resource',
                 supportsPartialValues=True,
                 remote=remote,
                 replaceOnChanges=replace_on_changes,
+                retainOnDelete=opts.retain_on_delete or False,
             )
 
             from ..resource import create_urn  # pylint: disable=import-outside-toplevel
+
             mock_urn = await create_urn(name, ty, resolver.parent_urn).future()
 
             def do_rpc_call():
                 if monitor is None:
                     # If no monitor is available, we'll need to fake up a response, for testing.
-                    return RegisterResponse(mock_urn, None, resolver.serialized_props, None)
+                    return RegisterResponse(
+                        mock_urn, None, resolver.serialized_props, None
+                    )
 
                 # If there is a monitor available, make the true RPC request to the engine.
                 try:
@@ -525,7 +606,9 @@ def register_resource(res: 'Resource',
 
             resp = await asyncio.get_event_loop().run_in_executor(None, do_rpc_call)
         except Exception as exn:
-            log.debug(f"exception when preparing or executing rpc: {traceback.format_exc()}")
+            log.debug(
+                f"exception when preparing or executing rpc: {traceback.format_exc()}"
+            )
             rpc.resolve_outputs_due_to_exception(resolvers, exn)
             resolve_urn(None, True, False, exn)
             if resolve_id is not None:
@@ -567,7 +650,14 @@ def register_resource(res: 'Resource',
                     urns = list(v.urns)
                     deps[k] = set(map(new_dependency, urns))
 
-            rpc.resolve_outputs(res, resolver.serialized_props, resp.object, deps, resolvers, transform_using_type_metadata)
+            rpc.resolve_outputs(
+                res,
+                resolver.serialized_props,
+                resp.object,
+                deps,
+                resolvers,
+                transform_using_type_metadata,
+            )
             resolve_outputs_called = True
 
         except Exception as exn:
@@ -584,19 +674,22 @@ def register_resource(res: 'Resource',
 
             raise
 
-    asyncio.ensure_future(RPC_MANAGER.do_rpc(
-        "register resource", do_register)())
+    asyncio.ensure_future(RPC_MANAGER.do_rpc("register resource", do_register)())
 
 
-def register_resource_outputs(res: 'Resource', outputs: 'Union[Inputs, Output[Inputs]]'):
+def register_resource_outputs(
+    res: "Resource", outputs: "Union[Inputs, Output[Inputs]]"
+):
     async def do_register_resource_outputs():
         urn = await res.urn.future()
         serialized_props = await rpc.serialize_properties(outputs, {})
         log.debug(
-            f"register resource outputs prepared: urn={urn}, props={serialized_props}")
+            f"register resource outputs prepared: urn={urn}, props={serialized_props}"
+        )
         monitor = settings.get_monitor()
         req = resource_pb2.RegisterResourceOutputsRequest(
-            urn=urn, outputs=serialized_props)
+            urn=urn, outputs=serialized_props
+        )
 
         def do_rpc_call():
             if monitor is None:
@@ -611,10 +704,12 @@ def register_resource_outputs(res: 'Resource', outputs: 'Union[Inputs, Output[In
 
         await asyncio.get_event_loop().run_in_executor(None, do_rpc_call)
         log.debug(
-            f"resource registration successful: urn={urn}, props={serialized_props}")
+            f"resource registration successful: urn={urn}, props={serialized_props}"
+        )
 
-    asyncio.ensure_future(RPC_MANAGER.do_rpc(
-        "register resource outputs", do_register_resource_outputs)())
+    asyncio.ensure_future(
+        RPC_MANAGER.do_rpc("register resource outputs", do_register_resource_outputs)()
+    )
 
 
 class PropertyDependencies:
@@ -631,11 +726,13 @@ class RegisterResponse:
     propertyDependencies: Optional[Dict[str, PropertyDependencies]]
 
     # pylint: disable=redefined-builtin
-    def __init__(self,
-                 urn: str,
-                 id: Optional[str],
-                 object: struct_pb2.Struct,
-                 propertyDependencies: Optional[Dict[str, PropertyDependencies]]):
+    def __init__(
+        self,
+        urn: str,
+        id: Optional[str],
+        object: struct_pb2.Struct,
+        propertyDependencies: Optional[Dict[str, PropertyDependencies]],
+    ):
         self.urn = urn
         self.id = id
         self.object = object
@@ -643,9 +740,11 @@ class RegisterResponse:
 
 
 def convert_providers(
-        provider: Optional['ProviderResource'],
-        providers: Optional[Union[Mapping[str, 'ProviderResource'],
-                                  Sequence['ProviderResource']]]) -> Mapping[str, 'ProviderResource']:
+    provider: Optional["ProviderResource"],
+    providers: Optional[
+        Union[Mapping[str, "ProviderResource"], Sequence["ProviderResource"]]
+    ],
+) -> Mapping[str, "ProviderResource"]:
     """
     Merge all providers opts (opts.provider and both list and dict forms of opts.providers) into a single dict.
     """
@@ -665,7 +764,9 @@ def convert_providers(
     return result
 
 
-async def _add_dependency(deps: Set[str], res: 'Resource', from_resource: Optional['Resource']):
+async def _add_dependency(
+    deps: Set[str], res: "Resource", from_resource: Optional["Resource"]
+):
     """
     _add_dependency adds a dependency on the given resource to the set of deps.
 
@@ -696,7 +797,7 @@ async def _add_dependency(deps: Set[str], res: 'Resource', from_resource: Option
     * Comp3 and Cust5 because Comp3 is a child of a remote component resource
     """
 
-    from .. import ComponentResource # pylint: disable=import-outside-toplevel
+    from .. import ComponentResource  # pylint: disable=import-outside-toplevel
 
     if isinstance(res, ComponentResource):
         for child in res._childResources:
@@ -711,7 +812,9 @@ async def _add_dependency(deps: Set[str], res: 'Resource', from_resource: Option
             deps.add(urn)
 
 
-async def _expand_dependencies(deps: Iterable['Resource'], from_resource: Optional['Resource']) -> Set[str]:
+async def _expand_dependencies(
+    deps: Iterable["Resource"], from_resource: Optional["Resource"]
+) -> Set[str]:
     """
     _expand_dependencies expands the given iterable of Resources into a set of URNs.
     """
@@ -723,7 +826,9 @@ async def _expand_dependencies(deps: Iterable['Resource'], from_resource: Option
     return urns
 
 
-async def _resolve_depends_on_urns(options: 'ResourceOptions', from_resource: 'Resource') -> Set[str]:
+async def _resolve_depends_on_urns(
+    options: "ResourceOptions", from_resource: "Resource"
+) -> Set[str]:
     """
     Resolves the set of all dependent resources implied by
     `depends_on`, either directly listed or implied in the Input
